@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
-
+import asyncio
 import pytest
+
 from pook import api
 
 
@@ -41,10 +41,35 @@ def test_mock_contructors(engine):
     assert engine.active is False
     assert engine.isdone() is True
 
-    api.mock('foo.com')
+    api.mock("foo.com")
     assert engine.isdone() is False
     assert len(engine.mocks) == 1
     api.off()
 
     assert len(engine.mocks) == 0
     assert engine.active is False
+
+
+def test_activate_as_decorator(engine):
+    @api.activate
+    def test_activate():
+        api.get("foo.com")
+        assert engine.active is True
+        assert engine.isdone() is False
+
+    test_activate()
+    assert engine.active is False
+    assert engine.isdone() is True
+
+
+async def test_activate_as_decorator_for_async(engine):
+    @api.activate
+    async def test_activate():
+        await asyncio.sleep(0)
+        api.get("foo.com")
+        assert engine.active is True
+        assert engine.isdone() is False
+
+    await test_activate()
+    assert engine.active is False
+    assert engine.isdone() is True
