@@ -1,7 +1,9 @@
-# -*- coding: utf-8 -*-
+from urllib.request import Request, urlopen
 
 import pytest
-from pook import MockEngine, Engine
+
+import pook
+from pook import Engine, MockEngine
 from pook.interceptors import BaseInterceptor
 
 
@@ -36,7 +38,7 @@ def test_mock_engine_interceptors(engine):
     assert len(engine.interceptors) == 1
     assert isinstance(engine.interceptors[0], Interceptor)
 
-    engine.remove_interceptor('Interceptor')
+    engine.remove_interceptor("Interceptor")
     assert len(engine.interceptors) == 0
 
 
@@ -51,3 +53,19 @@ def test_mock_engine_status(engine):
 
     engine.disable()
     assert not interceptor.active
+
+
+@pytest.mark.xfail(
+    reason="Pook cannot disambiguate the two mocks. Ideally it would try to find the most specific mock that matches, but that's not possible yet."
+)
+@pytest.mark.pook(allow_pending_mocks=True)
+def test_mock_specificity(httpbin):
+    url404 = f"{httpbin.url}/status/404"
+    pook.get(url404).header_present("authorization").reply(201)
+    pook.get(url404).headers({"Authorization": "Bearer pook"}).reply(200)
+
+    res_with_headers = urlopen(
+        Request(url404, headers={"Authorization": "Bearer pook"})
+    )
+
+    assert res_with_headers.status == 200
